@@ -1019,7 +1019,7 @@ class Builder(Update):
         pkgdir = self.clVars.Get('cl_builder_pkgdir_full')
         os.system(
             '/usr/bin/chroot %s /bin/bash -c '
-            '"PKGDIR=%s /usr/sbin/emaint binhost -f &>/dev/null' %
+            '"PKGDIR=%s /usr/sbin/emaint binhost -f" &>/dev/null' %
             (chroot_path, pkgdir))
 
     def cleanpkg(self):
