@@ -826,6 +826,19 @@ class VariableClBuilderPkgdirStable(Variable):
     value_format = "{cl_builder_pkgdir}.stable"
 
 
+class VariableClBuilderPkgdirFull(ReadonlyVariable):
+    """
+    Директория с полным набором бинарных пакетов зависит
+    от того использует ли builder base бинхост
+    """
+
+    def get(self):
+        if self.GetBool('cl_builder_binhost_base_set'):
+            return self.Get('cl_builder_pkgdir_stable')
+        else:
+            return self.Get('cl_builder_pkgdir')
+
+
 class VariableClBuilderPkgdirTrunk(Variable):
     """
     Директория со набором бинарных пакетов, осавшихся в результате
